mriqc.reports package — mriqc 0.1.0 documentation

# mriqc.reports package

## Submodules

## mriqc.reports.generators module

Encapsulates report generation functions

`mriqc.reports.generators.` `concat_pdf`(in_files, out_file='concatenated.pdf')

  Concatenate PDF list (http://stackoverflow.com/a/3444735)

`mriqc.reports.generators.` `get_documentation`(doc_type, out_file)

  Generates the documentation page

`mriqc.reports.generators.` `report_anatomical`(dframe, subject=None, sc_split=False, condensed=True, out_file='anatomical.pdf')

  Calls the report generator on the functional measures

`mriqc.reports.generators.` `report_functional`(dframe, subject=None, sc_split=False, condensed=True, out_file='functional.pdf')

  Calls the report generator on the functional measures

`mriqc.reports.generators.` `summary_cover`(data, is_group=False, out_file=None)

  Generates a cover page with subject information

`mriqc.reports.generators.` `workflow_report`(in_csv, qctype, sub_list=None, settings=None)

  Creates the report

## mriqc.reports.utils module

Helpers in report generation

`mriqc.reports.utils.` `find_failed`(dframe, sub_list)

  Identify failed subjects

`mriqc.reports.utils.` `image_parameters`(dframe)

  Generate formatted parameters for each subject, session and scan

`mriqc.reports.utils.` `read_csv`(in_csv)

  Read csv file, sort and drop duplicates

## Module contents

Reports module